==> zio-aws-sagemaker_2.12-6.20.120.1-sources.jar: zio/aws/sagemaker/model/SelectiveExecutionResult.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.PipelineExecutionArn
import scala.jdk.CollectionConverters._
final case class SelectiveExecutionResult(
    sourcePipelineExecutionArn: Optional[PipelineExecutionArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.SelectiveExecutionResult = {
    import SelectiveExecutionResult.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.SelectiveExecutionResult
      .builder()
      .optionallyWith(
        sourcePipelineExecutionArn.map(value =>
          PipelineExecutionArn.unwrap(value): java.lang.String
        )
      )(_.sourcePipelineExecutionArn)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.SelectiveExecutionResult.ReadOnly =
    zio.aws.sagemaker.model.SelectiveExecutionResult.wrap(buildAwsValue())
}
object SelectiveExecutionResult {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.SelectiveExecutionResult
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.SelectiveExecutionResult =
      zio.aws.sagemaker.model.SelectiveExecutionResult(
        sourcePipelineExecutionArn.map(value => value)
      )
    def sourcePipelineExecutionArn: Optional[PipelineExecutionArn]
    def getSourcePipelineExecutionArn
        : ZIO[Any, AwsError, PipelineExecutionArn] = AwsError.unwrapOptionField(
      "sourcePipelineExecutionArn",
      sourcePipelineExecutionArn
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.SelectiveExecutionResult
  ) extends zio.aws.sagemaker.model.SelectiveExecutionResult.ReadOnly {
    override val sourcePipelineExecutionArn: Optional[PipelineExecutionArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sourcePipelineExecutionArn())
        .map(value =>
          zio.aws.sagemaker.model.primitives.PipelineExecutionArn(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.SelectiveExecutionResult
  ): zio.aws.sagemaker.model.SelectiveExecutionResult.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-sagemaker_3-7.21.15.7-sources.jar: zio/aws/sagemaker/model/SelectiveExecutionResult.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.PipelineExecutionArn
import scala.jdk.CollectionConverters.*
final case class SelectiveExecutionResult(
    sourcePipelineExecutionArn: Optional[PipelineExecutionArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.SelectiveExecutionResult = {
    import SelectiveExecutionResult.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.SelectiveExecutionResult
      .builder()
      .optionallyWith(
        sourcePipelineExecutionArn.map(value =>
          PipelineExecutionArn.unwrap(value): java.lang.String
        )
      )(_.sourcePipelineExecutionArn)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.SelectiveExecutionResult.ReadOnly =
    zio.aws.sagemaker.model.SelectiveExecutionResult.wrap(buildAwsValue())
}
object SelectiveExecutionResult {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.SelectiveExecutionResult
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.SelectiveExecutionResult =
      zio.aws.sagemaker.model.SelectiveExecutionResult(
        sourcePipelineExecutionArn.map(value => value)
      )
    def sourcePipelineExecutionArn: Optional[PipelineExecutionArn]
    def getSourcePipelineExecutionArn
        : ZIO[Any, AwsError, PipelineExecutionArn] = AwsError.unwrapOptionField(
      "sourcePipelineExecutionArn",
      sourcePipelineExecutionArn
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.SelectiveExecutionResult
  ) extends zio.aws.sagemaker.model.SelectiveExecutionResult.ReadOnly {
    override val sourcePipelineExecutionArn: Optional[PipelineExecutionArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sourcePipelineExecutionArn())
        .map(value =>
          zio.aws.sagemaker.model.primitives.PipelineExecutionArn(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.SelectiveExecutionResult
  ): zio.aws.sagemaker.model.SelectiveExecutionResult.ReadOnly = new Wrapper(
    impl
  )
}
